<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>ara mateix</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 missatge nou</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>fa %1 minuts</translation>
    </message>
</context>
</TS>